pub struct WithRoute<'a, T: ?Sized, Route> { /* private fields */ }Trait Implementations
Sourceimpl<Route: Clone, Msg, E, T: ?Sized + RouteSink<Route, Msg, Error = E>> Sink<Msg> for WithRoute<'_, T, Route>
impl<Route: Clone, Msg, E, T: ?Sized + RouteSink<Route, Msg, Error = E>> Sink<Msg> for WithRoute<'_, T, Route>
Sourcefn poll_ready(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
) -> Poll<Result<(), Self::Error>>
fn poll_ready( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Result<(), Self::Error>>
Attempts to prepare the
Sink to receive a value. Read moreSourcefn start_send(self: Pin<&mut Self>, msg: Msg) -> Result<(), Self::Error>
fn start_send(self: Pin<&mut Self>, msg: Msg) -> Result<(), Self::Error>
Begin the process of sending a value to the sink.
Each call to this function must be preceded by a successful call to
poll_ready which returned Poll::Ready(Ok(())). Read moreimpl<T: ?Sized, Route> Unpin for WithRoute<'_, T, Route>